@@ -13,23 +13,26 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
-from os.path import join
-from octobot_commons.constants import USER_FOLDER, CONFIG_FOLDER
+import os.path as path
+import octobot_commons.constants as constants
+import octobot_commons.enums as enums
 
 # Default tests tentacles URL
 DEFAULT_TENTACLES_URL = "https://www.tentacles.octobot.online/repository/tentacles/officials/base/tests/0.0.2-tests.zip"
+DEFAULT_BOT_INSTALL_DIR = "."
 
 # Tentacles files
 PYTHON_INIT_FILE = "__init__.py"
+CYTHON_HEADER_INIT_FILE = "__init__.pxd"
 PYTHON_EXT = ".py"
-CONFIG_EVALUATOR_FILE = "evaluator_config.json"
-CONFIG_TRADING_FILE = "trading_config.json"
+CYTHON_EXT = ".pxd"
 CONFIG_TENTACLES_FILE = "tentacles_config.json"
 CONFIG_EXT = ".json"
 DOCUMENTATION_EXT = ".md"
 CONFIG_SCHEMA_EXT = "_schema.json"
 TENTACLE_METADATA = "metadata.json"
-DEFAULT_TENTACLE_CONFIG = join(CONFIG_FOLDER, "default_tentacles_config.json")
+DEFAULT_TENTACLE_CONFIG = path.join(constants.CONFIG_FOLDER, "default_tentacles_config.json")
+
 # tentacles setup folders back list
 FOLDERS_BLACK_LIST = ["__pycache__"]
 
@@ -39,23 +42,28 @@ METADATA_TENTACLES = "tentacles"
 METADATA_ORIGIN_PACKAGE = "origin_package"
 METADATA_DEV_MODE = "dev_mode"
 METADATA_TENTACLES_REQUIREMENTS = "tentacles-requirements"
+METADATA_TENTACLES_GROUP = "tentacles_group"
 
 # Requirements
 TENTACLE_REQUIREMENT_VERSION_EQUALS = "=="
 
 # Tentacle user config files and folders
-USER_TENTACLE_CONFIG_PATH = join(USER_FOLDER, "tentacles_config")
-USER_TENTACLE_CONFIG_FILE_PATH = join(USER_TENTACLE_CONFIG_PATH, CONFIG_TENTACLES_FILE)
-USER_TENTACLE_SPECIFIC_CONFIG_PATH = join(USER_TENTACLE_CONFIG_PATH, "specific_config")
+USER_TENTACLE_CONFIG_PATH = path.join(constants.USER_FOLDER, "tentacles_config")
+USER_TENTACLE_CONFIG_FILE_PATH = path.join(USER_TENTACLE_CONFIG_PATH, CONFIG_TENTACLES_FILE)
+USER_TENTACLE_SPECIFIC_CONFIG_PATH = path.join(USER_TENTACLE_CONFIG_PATH, "specific_config")
 
 # Current minimum default tentacles version
 TENTACLE_CURRENT_MINIMUM_DEFAULT_TENTACLES_VERSION = "1.2.0"
 DEFAULT_TENTACLES_PACKAGE = "OctoBot-Default-Tentacles"
 
+# Tentacles packages
+UNKNOWN_TENTACLES_PACKAGE_LOCATION = "Unknown package location"
+
 # Tentacles installation folders
 TENTACLES_INSTALL_TEMP_DIR = "temp_tentacles"
 TENTACLES_REQUIREMENTS_INSTALL_TEMP_DIR = "requirements_temp_tentacles"
 TENTACLES_ARCHIVE_ROOT = "reference_tentacles"
+TO_REMOVE_FOLDER = "_to_rm"
 
 # Tentacles folders
 TENTACLES_PATH = "tentacles"
@@ -91,24 +99,22 @@ TENTACLE_RESOURCES = "resources"
 TENTACLE_TESTS = "tests"
 
 # Tentacle creator
-TENTACLES_PACKAGE_CREATOR_TEMP_FOLDER = "creator_tentacles_temp"
+TENTACLES_PACKAGE_CREATOR_TEMP_FOLDER = "creator_temp"
 TENTACLES_PACKAGE_FORMAT = "zip"
-PYTHON_GENERATED_ELEMENTS = ["__pycache__"]
-PYTHON_GENERATED_ELEMENTS_EXTENSION = ["pyc"]
+PYTHON_GENERATED_ELEMENTS = {"__pycache__"}
+TENTACLES_PACKAGE_IGNORED_ELEMENTS = [".git", ".coveragerc", ".gitignore", ".travis.yml",
+                                      "azure-pipelines.yml", "octobot_config.json"]
+COMPILED_TENTACLES_TO_REMOVE_FOLDERS = {"build", "temp", "tests"}
+PYTHON_GENERATED_ELEMENTS_EXTENSION = {"pyc"}
+COMPILED_TENTACLES_TO_KEEP_ELEMENTS = {PYTHON_INIT_FILE}
+COMPILED_TENTACLES_TO_REMOVE_ELEMENTS = {".c", ".py", ".pxd", ".pyc", "tests"}
 TENTACLE_TEMPLATE_PATH = "templates"
 TENTACLE_TEMPLATE_DESCRIPTION = "description"
 TENTACLE_CONFIG_TEMPLATE_PRE_EXT = "_config"
 TENTACLE_TEMPLATE_EXT = ".template"
 TENTACLE_TEMPLATE_PRE_EXT = "_tentacle"
-
-# Tentacles that can be activated / deactivated
-ACTIVATABLE_TENTACLES = [
-    TENTACLES_EVALUATOR_REALTIME_PATH,
-    TENTACLES_EVALUATOR_SOCIAL_PATH,
-    TENTACLES_EVALUATOR_TA_PATH,
-    TENTACLES_EVALUATOR_STRATEGIES_PATH,
-    TENTACLES_TRADING_MODE_PATH,
-]
+CYTHON_PXD_HEADER = "# cython: language_level=3"
+SETUP_FILE = "setup.py"
 
 # Tentacles architecture
 TENTACLES_FOLDERS_ARCH = {
@@ -158,3 +164,10 @@ TENTACLE_TYPES = [
     TENTACLES_SERVICES_PATH,
     TENTACLES_TRADING_PATH
 ]
+
+# compiled tentacles paths
+PLATFORM_TO_DOWNLOAD_PATH = {
+    enums.PlatformsName.WINDOWS: "windows",
+    enums.PlatformsName.LINUX: "linux",
+    enums.PlatformsName.MAC: "macos",
+}
\ No newline at end of file
