@@ -27,8 +27,10 @@ from octobot_tentacles_manager.api.installer import install_all_tentacles, insta
 from octobot_tentacles_manager.configuration.tentacles_setup_configuration import TentaclesSetupConfiguration
 from octobot_tentacles_manager.constants import TENTACLES_PATH, TENTACLES_REQUIREMENTS_INSTALL_TEMP_DIR, \
     PYTHON_INIT_FILE, TENTACLES_NOTIFIERS_PATH, USER_TENTACLE_CONFIG_PATH, CONFIG_TENTACLES_FILE, \
-    USER_TENTACLE_SPECIFIC_CONFIG_PATH, TENTACLES_SERVICES_PATH, TENTACLES_BACKTESTING_PATH
+    USER_TENTACLE_SPECIFIC_CONFIG_PATH, TENTACLES_SERVICES_PATH, TENTACLES_BACKTESTING_PATH, TENTACLES_EVALUATOR_PATH
 from octobot_tentacles_manager.managers.tentacles_setup_manager import TentaclesSetupManager
+from tests import event_loop
+
 
 # All test coroutines will be treated as marked.
 pytestmark = pytest.mark.asyncio
@@ -100,7 +102,9 @@ async def test_repair_installation():
     user_config_path = path.join(broken_install, USER_TENTACLE_CONFIG_PATH)
     with open(path.join(user_config_path, CONFIG_TENTACLES_FILE)) as f:
         activations = json.load(f)[TentaclesSetupConfiguration.TENTACLE_ACTIVATION_KEY]
-        assert activations["SecondOtherInstantFluctuationsEvaluator"] is False
+        # SecondOtherInstantFluctuationsEvaluator is activated because there is no available default config in
+        # this context
+        assert activations[TENTACLES_EVALUATOR_PATH]["SecondOtherInstantFluctuationsEvaluator"] is True
 
     # restore DailyTradingMode config file
     assert path.isfile(path.join(broken_install, USER_TENTACLE_SPECIFIC_CONFIG_PATH, "DailyTradingMode.json"))
